# このライブラリを使う際は自己責任でお願いします
## 実装済モジュール
### 最大公約数 gcd(int a,int b)
引数に入れた二つの整数a,bの最大公約数を返します。
中身はユークリッドの互除法です。

### 部分和判断　partial_sum(int n,int v,list a)
n個の整数a1,a2...anからいくつかの整数を選んで総和をとった場合、総和をvにすることができるかの判断を行うモジュールです。
返り値はboolean型で上記が真の場合True,偽の場合Falseで返します。


This project is licensed under the MIT License, see the LICENSE.txt file for details